==> docute-4.16.2.tgz: package/lib/utils/cssVariables.js <==
var defaultCssVariables = {
  pageBackground: 'white',
  headerBackground: 'white',
  textColor: '#000',
  linkColor: '#000',
  accentColor: '#3eaf7c',
  sidebarWidth: '280px',
  sidebarBackground: 'white',
  sidebarSectionTitleColor: 'rgb(136, 136, 136)',
  borderColor: '#eaeaea',
  headerHeight: '55px',
  codeFont: 'SFMono-Regular,Consolas,Liberation Mono,Menlo,Courier,monospace',
  tipColor: 'rgb(6, 125, 247)',
  successColor: '#42b983',
  warningColor: '#ff9800',
  dangerColor: 'rgb(255, 0, 31)',
  navLinkColor: '#2c3e50',
  navLinkHoverBorderColor: '#e2e2e2',
  codeBlockBackground: '#fdfaf6',
  codeBlockShadowColor: '#faede5',
  codeBlockShadowWidth: '1px',
  highlightedLineBackground: '#faede5',
  highlightedLineBorderColor: '#f1beb6',
  inlineCodeColor: 'inherit',
  inlineCodeBackground: '#fdfaf6',
  loaderPrimaryColor: '#f3f3f3',
  loaderSecondaryColor: '#ecebeb',
  tableHeaderBackground: '#fafafa',
  tableHeaderColor: '#666',
  docuteSelectHeight: '38px'
};
var darkCssVariables = Object.assign({}, defaultCssVariables, {
  pageBackground: '#2f3136',
  headerBackground: '#2f3136',
  sidebarBackground: '#2f3136',
  textColor: 'hsla(0,0%,100%,0.88)',
  accentColor: '#0096cf',
  linkColor: 'currentColor',
  navLinkColor: 'var(--text-color)',
  codeBlockBackground: '#011627',
  codeBlockShadowColor: '#333',
  codeBlockShadowWidth: '0px',
  borderColor: '#3e4147',
  highlightedLineBackground: '#022a4b',
  highlightedLineBorderColor: '#ffa7c4',
  inlineCodeColor: '#e6e6e6',
  inlineCodeBackground: '#373c49',
  loaderPrimaryColor: 'hsla(0, 0%, 100%, 0.08)',
  loaderSecondaryColor: 'hsla(0, 0%, 100%, 0.18)',
  contentLinkBorder: '2px solid hsla(0, 0%, 100%, 0.28)',
  contentLinkHoverBorderColor: 'currentColor',
  tableHeaderBackground: 'var(--border-color)',
  tableHeaderColor: '#868686'
});
export { defaultCssVariables, darkCssVariables };

==> docute-4.19.0.tgz: package/lib/utils/cssVariables.js <==
var defaultCssVariables = {
  pageBackground: 'white',
  headerBackground: 'white',
  textColor: '#000',
  linkColor: '#000',
  accentColor: '#3eaf7c',
  sidebarWidth: '280px',
  sidebarBackground: 'white',
  sidebarSectionTitleColor: 'rgb(136, 136, 136)',
  borderColor: '#eaeaea',
  headerHeight: '55px',
  codeFont: 'SFMono-Regular,Consolas,Liberation Mono,Menlo,Courier,monospace',
  tipColor: 'rgb(6, 125, 247)',
  successColor: '#42b983',
  warningColor: '#ff9800',
  dangerColor: 'rgb(255, 0, 31)',
  navLinkColor: '#2c3e50',
  navLinkHoverBorderColor: '#e2e2e2',
  codeBlockBackground: '#fdfaf6',
  codeBlockShadowColor: '#faede5',
  codeBlockShadowWidth: '1px',
  highlightedLineBackground: '#faede5',
  highlightedLineBorderColor: '#f1beb6',
  inlineCodeColor: 'inherit',
  inlineCodeBackground: '#fdfaf6',
  loaderPrimaryColor: '#f3f3f3',
  loaderSecondaryColor: '#ecebeb',
  tableHeaderBackground: '#fafafa',
  tableHeaderColor: '#666',
  docuteSelectHeight: '38px',
  searchIconColor: '#999',
  searchFocusBorderColor: '#ccc',
  searchFocusIconColor: '#333',
  searchResultHoverBackground: '#f9f9f9'
};
var darkCssVariables = Object.assign({}, defaultCssVariables, {
  pageBackground: '#2f3136',
  headerBackground: '#2f3136',
  sidebarBackground: '#2f3136',
  textColor: 'hsla(0,0%,100%,0.88)',
  accentColor: '#0096cf',
  linkColor: 'currentColor',
  navLinkColor: 'var(--text-color)',
  codeBlockBackground: '#011627',
  codeBlockShadowColor: '#333',
  codeBlockShadowWidth: '0px',
  borderColor: '#3e4147',
  highlightedLineBackground: '#022a4b',
  highlightedLineBorderColor: '#ffa7c4',
  inlineCodeColor: '#e6e6e6',
  inlineCodeBackground: '#373c49',
  loaderPrimaryColor: 'hsla(0, 0%, 100%, 0.08)',
  loaderSecondaryColor: 'hsla(0, 0%, 100%, 0.18)',
  contentLinkBorder: '2px solid hsla(0, 0%, 100%, 0.28)',
  contentLinkHoverBorderColor: 'currentColor',
  tableHeaderBackground: 'var(--border-color)',
  tableHeaderColor: '#868686',
  searchIconColor: '#999',
  searchFocusBorderColor: '#999',
  searchFocusIconColor: '#ccc',
  searchResultBackground: '#27292f',
  searchResultHoverBackground: '#1e2025'
});
export { defaultCssVariables, darkCssVariables };
